@@ -1,6 +1,6 @@
-#!/usr/bin/env python
+#!/usr/local/bin/python2.7
 #******************************************************************************
-#  $Id: epsg_tr.py 18953 2010-02-28 12:00:54Z rouault $
+#  $Id: epsg_tr.py 19102 2010-03-15 23:41:44Z warmerdam $
 # 
 #  Project:  CFS OGC MapServer
 #  Purpose:  Script to create WKT and PROJ.4 dictionaries for EPSG GCS/PCS
@@ -115,7 +115,20 @@ def trHandleCode(code, gen_dict_line, report_error, output_format):
                 proj4text = gdal.EscapeString(proj4text,scheme=gdal.CPLES_SQL)
                 print('INSERT INTO "spatial_ref_sys" ("srid","auth_name","auth_srid","srtext","proj4text") VALUES (%s,\'EPSG\',%s,\'%s\',\'%s\');' % \
                       (str(code),str(code),wkt,proj4text))
+
+        # INGRES COPY command input.
+        if output_format == '-copy':
             
+            try:
+                wkt = prj_srs.ExportToWkt()
+                proj4text = prj_srs.ExportToProj4()
+
+                print( '%d\t%d%s\t%d\t%d%s\t%d%s\n' \
+                       % (code,4,'EPSG',code,len(wkt),wkt,
+                          len(proj4text),proj4text))
+            except:
+                pass
+
 # =============================================================================
 
 if __name__ == '__main__':
@@ -137,7 +150,7 @@ if __name__ == '__main__':
         arg = argv[i]
 
         if arg == '-wkt' or arg == '-pretty_wkt' or arg == '-proj4' \
-           or arg == '-postgis' or arg == '-xml':
+           or arg == '-postgis' or arg == '-xml' or arg == '-copy':
             output_format = arg
 
         elif arg[:5] == '-skip':
